import { DatetimeMixin } from './DatetimeMixin'

export const RuleMixin = {
    mixins: [DatetimeMixin],
    methods: {
        /**
        * Validates if specified value is filled in.
        *
        * @returns { Array<Boolean> } true - Rule passed
        * @returns { Array<String> } error - Text with particular error
        */
        required_rule() {
            return [ val => !!val || this.$t('common:field_required') ]
        },
        /**
         * Validates if value doesn't have invalid range.
         *
         * @param { String } time_begin_from
         * @param { String } time_begin_to
         * @returns { Array<Boolean> } true - Rule passed
         * @returns { Array<String> } error - Text with particular error
         */
        less_than_rule(time_begin_from, time_begin_to) {
            if (time_begin_from === null || time_begin_to === null) {
                return [true]
            }
            return [
                () => this.is_less_than(time_begin_from, time_begin_to)
                || this.$t('common:range_rule'),
            ]
        },
        /**
         * Checks email validity
         *
         * @returns { Array<Boolean> } - array with true of false
         */
        email_rule(value) {
            return [ value.every(email => /^\w+([.-]?\w+)*@\w+([.-]?\w+)*(\.\w{2,3})+$/.test(email)) ]
        },
        /**
         * Checks phone validity
         *
         * @returns { Array<Boolean> } - array with true of false
         */
        phone_rule(value) {
            return [ value.every(phone => /^\+\d+\.[0-9]+$/.test(phone)) ]
        },
    },
}
